@@ -17,15 +17,15 @@
 #' @inheritParams adjust_emc_sel
 #' @param u_model_coefs The regression coefficients corresponding to the model:
 #'  \ifelse{html}{\out{logit(P(U=1)) = &alpha;<sub>0</sub> + &alpha;<sub>1</sub>X + &alpha;<sub>2</sub>Y + &alpha;<sub>2+j</sub>C<sub>j</sub>, }}{\eqn{logit(P(U=1)) = \alpha_0 + \alpha_1 X + \alpha_2 Y + \alpha_{2+j} C_j, }}
-#'  where U is the binary unmeasured
-#'  confounder, X is the binary exposure, Y is the binary outcome, C
-#'  represents the vector of binary measured confounders (if any), and j
+#'  where \emph{U} is the binary unmeasured
+#'  confounder, \emph{X} is the exposure, \emph{Y} is the outcome, \emph{C}
+#'  represents the vector of binary measured confounders (if any), and \emph{j}
 #'  corresponds to the number of measured confounders. The number of parameters
-#'  therefore equals 3 + j.
+#'  therefore equals 3 + \emph{j}.
 #' @param s_model_coefs The regression coefficients corresponding to the model:
 #'  \ifelse{html}{\out{logit(P(S=1)) = &beta;<sub>0</sub> + &beta;<sub>1</sub>X + &beta;<sub>2</sub>Y, }}{\eqn{logit(P(S=1)) = \beta_0 + \beta_1 X + \beta_2 Y, }}
-#'  where S represents binary selection, X is the binary exposure,
-#'  and Y is the binary outcome.
+#'  where \emph{S} represents binary selection, \emph{X} is the exposure,
+#'  and \emph{Y} is the outcome.
 #'  The number of parameters therefore equals 3.
 #' @return A list where the first item is the odds ratio estimate of the
 #'  effect of the exposure on the outcome and the second item is the
@@ -45,6 +45,7 @@
 #' @importFrom magrittr %>%
 #' @importFrom stats binomial
 #' @importFrom stats glm
+#' @importFrom stats lm
 #' @importFrom stats qnorm
 #' @importFrom stats plogis
 #' @importFrom rlang .data
@@ -69,12 +70,12 @@ adjust_uc_sel <- function(
   x <- data[, exposure]
   y <- data[, outcome]
 
-  if (sum(x %in% c(0, 1)) != n) {
-    stop("Exposure must be a binary integer.")
-  }
-  if (sum(y %in% c(0, 1)) != n) {
-    stop("Outcome must be a binary integer.")
+  if (sum(y %in% c(0, 1)) == n) {
+    y_binary <- TRUE
+  } else {
+    y_binary <- FALSE
   }
+
   if (len_u_coefs != 3 + len_c) {
     stop(
       paste0(
@@ -108,14 +109,24 @@ adjust_uc_sel <- function(
              pU = case_when(Ubar == 1 ~ u1_pred,
                             Ubar == 0 ~ 1 - u1_pred))
 
-    suppressWarnings({
-      final <- glm(
-        Y ~ X + Ubar,
-        family = binomial(link = "logit"),
-        weights = (combined$pU / combined$pS),
-        data = combined
-      )
-    })
+    if (y_binary) {
+      suppressWarnings({
+        final <- glm(
+          Y ~ X + Ubar,
+          family = binomial(link = "logit"),
+          weights = (combined$pU / combined$pS),
+          data = combined
+        )
+      })
+    } else {
+      suppressWarnings({
+        final <- lm(
+          Y ~ X + Ubar,
+          weights = (combined$pU / combined$pS),
+          data = combined
+        )
+      })
+    }
 
   } else if (len_c == 1) {
 
@@ -132,14 +143,24 @@ adjust_uc_sel <- function(
              pU = case_when(Ubar == 1 ~ u1_pred,
                             Ubar == 0 ~ 1 - u1_pred))
 
-    suppressWarnings({
-      final <- glm(
-        Y ~ X + C1 + Ubar,
-        family = binomial(link = "logit"),
-        weights = (combined$pU / combined$pS),
-        data = combined
-      )
-    })
+    if (y_binary) {
+      suppressWarnings({
+        final <- glm(
+          Y ~ X + C1 + Ubar,
+          family = binomial(link = "logit"),
+          weights = (combined$pU / combined$pS),
+          data = combined
+        )
+      })
+    } else {
+      suppressWarnings({
+        final <- lm(
+          Y ~ X + C1 + Ubar,
+          weights = (combined$pU / combined$pS),
+          data = combined
+        )
+      })
+    }
 
   } else if (len_c == 2) {
 
@@ -160,14 +181,24 @@ adjust_uc_sel <- function(
              pU = case_when(Ubar == 1 ~ u1_pred,
                             Ubar == 0 ~ 1 - u1_pred))
 
-    suppressWarnings({
-      final <- glm(
-        Y ~ X + C1 + C2 + Ubar,
-        family = binomial(link = "logit"),
-        weights = (combined$pU / combined$pS),
-        data = combined
-      )
-    })
+    if (y_binary) {
+      suppressWarnings({
+        final <- glm(
+          Y ~ X + C1 + C2 + Ubar,
+          family = binomial(link = "logit"),
+          weights = (combined$pU / combined$pS),
+          data = combined
+        )
+      })
+    } else {
+      suppressWarnings({
+        final <- lm(
+          Y ~ X + C1 + C2 + Ubar,
+          weights = (combined$pU / combined$pS),
+          data = combined
+        )
+      })
+    }
 
   } else if (len_c == 3) {
 
@@ -191,28 +222,43 @@ adjust_uc_sel <- function(
              pU = case_when(Ubar == 1 ~ u1_pred,
                             Ubar == 0 ~ 1 - u1_pred))
 
-    suppressWarnings({
-      final <- glm(
-        Y ~ X + C1 + C2 + C3 + Ubar,
-        family = binomial(link = "logit"),
-        weights = (combined$pU / combined$pS),
-        data = combined
-      )
-    })
+    if (y_binary) {
+      suppressWarnings({
+        final <- glm(
+          Y ~ X + C1 + C2 + C3 + Ubar,
+          family = binomial(link = "logit"),
+          weights = (combined$pU / combined$pS),
+          data = combined
+        )
+      })
+    } else {
+      suppressWarnings({
+        final <- lm(
+          Y ~ X + C1 + C2 + C3 + Ubar,
+          weights = (combined$pU / combined$pS),
+          data = combined
+        )
+      })
+    }
 
   } else if (len_c > 3) {
-
     stop("This function is currently not compatible with >3 confounders.")
-
   }
 
   est <- summary(final)$coef[2, 1]
   se <- summary(final)$coef[2, 2]
   alpha <- 1 - level
 
-  estimate <- exp(est)
-  ci <- c(exp(est + se * qnorm(alpha / 2)),
-          exp(est + se * qnorm(1 - alpha / 2)))
+  if (y_binary) {
+    estimate <- exp(est)
+    ci <- c(exp(est + se * qnorm(alpha / 2)),
+            exp(est + se * qnorm(1 - alpha / 2)))
+  } else {
+    estimate <- est
+    ci <- c(est + se * qnorm(alpha / 2),
+            est + se * qnorm(1 - alpha / 2))
+  }
+
   return(list(estimate = estimate, ci = ci))
 
 }
\ No newline at end of file
